[Openswan dev] [PATCH] Correct usefull to useful

Jari Aalto jari.aalto at cante.net
Fri Mar 12 19:30:52 EST 2010


Signed-off-by: Jari Aalto <jari.aalto at cante.net>
---
 CHANGES                                        |    2 +-
 doc/draft-spencer-ipsec-ike-implementation.nr  |    2 +-
 doc/draft-spencer-ipsec-ike-implementation.txt |    2 +-
 doc/glossary.html                              |    2 +-
 doc/src/glossary.html                          |    2 +-
 linux/include/openswan/ipsec_alg.h             |    2 +-
 linux/net/ipsec/ipsec_xmit.c                   |    2 +-
 programs/barf/barf.8                           |    2 +-
 programs/pluto/connections.c                   |    2 +-
 programs/pluto/pluto.8                         |    2 +-
 programs/pluto/vendor.c                        |   22 +++++++++++-----------
 11 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/CHANGES b/CHANGES
index 1b53fc5..5b6d2aa 100644
--- a/CHANGES
+++ b/CHANGES
@@ -788,7 +788,7 @@ v2.1.0
 * X.509 fixes (Andreas Steffan)
 * New configuration file directive, {left|right}sourceip=#.#.#.# 
   This will set the source address when talking to a particular 
-  connection.  This is very usefull to assign a static IP to your laptop 
+  connection.  This is very useful to assign a static IP to your laptop 
   while travelling.  This is based on Tuomo Soini's Advanced Routing 
   patch.
 
diff --git a/doc/draft-spencer-ipsec-ike-implementation.nr b/doc/draft-spencer-ipsec-ike-implementation.nr
index 5b5776e..b695c2b 100644
--- a/doc/draft-spencer-ipsec-ike-implementation.nr
+++ b/doc/draft-spencer-ipsec-ike-implementation.nr
@@ -980,7 +980,7 @@ but we think this needs better specification.
 Further IKE challenges appear in the context of Opportunistic Encryption
 [OE],
 but operational experience with it is too limited as yet for us
-to comment usefully right now.
+to comment usefuly right now.
 .H
 6.7. Authentication and RSA Keys
 .P
diff --git a/doc/draft-spencer-ipsec-ike-implementation.txt b/doc/draft-spencer-ipsec-ike-implementation.txt
index 145c00b..121cb2b 100644
--- a/doc/draft-spencer-ipsec-ike-implementation.txt
+++ b/doc/draft-spencer-ipsec-ike-implementation.txt
@@ -939,7 +939,7 @@ Internet Draft          IKE Implementation Issues            26 Feb 2002
 
    Further IKE challenges appear in the context of Opportunistic
    Encryption [OE], but operational experience with it is too limited as
-   yet for us to comment usefully right now.
+   yet for us to comment usefuly right now.
 
 6.7. Authentication and RSA Keys
 
diff --git a/doc/glossary.html b/doc/glossary.html
index d7164d5..3e914c5 100644
--- a/doc/glossary.html
+++ b/doc/glossary.html
@@ -1425,7 +1425,7 @@ nit, the largest size of packet that can be sent over a link. This is
 <DD>A host which accepts, but does not initiate, requests for<A HREF="#carpediem">
  opportunistic encryption</A> (OE). An opportunistic responder has
  enabled OE in its<A HREF="#passive.OE"> passive</A> form (pOE) only. A
- web server or file server may be usefully set up as an opportunistic
+ web server or file server may be usefuly set up as an opportunistic
  responder.
 <P>Configuring passive OE is described in our<A href="policygroups.html#policygroups">
  policy groups</A> document.</P>
diff --git a/doc/src/glossary.html b/doc/src/glossary.html
index ca7d39b..f745637 100644
--- a/doc/src/glossary.html
+++ b/doc/src/glossary.html
@@ -1530,7 +1530,7 @@ href="#Z">Z</a></b></big></center>
      <A HREF="#carpediem">opportunistic encryption</A> (OE). 
      An opportunistic responder has enabled OE in its
      <A HREF="#passive.OE">passive</A> form (pOE) only.
-     A web server or file server may be usefully set up as an opportunistic 
+     A web server or file server may be usefuly set up as an opportunistic 
       responder. 
       <p>Configuring passive OE is described in our
       <a href="policygroups.html#policygroups">policy groups</a> document.</p>
diff --git a/linux/include/openswan/ipsec_alg.h b/linux/include/openswan/ipsec_alg.h
index 0ce058f..292b2b2 100644
--- a/linux/include/openswan/ipsec_alg.h
+++ b/linux/include/openswan/ipsec_alg.h
@@ -126,7 +126,7 @@ int register_ipsec_alg(struct ipsec_alg *);
 int unregister_ipsec_alg(struct ipsec_alg *);
 /*	-  optional (simple test) for algos 	*/
 int ipsec_alg_test(unsigned alg_type, unsigned alg_id, int testparm);
-/*	inline wrappers (usefull for type validation */
+/*	inline wrappers (useful for type validation */
 static inline int register_ipsec_alg_enc(struct ipsec_alg_enc *ixt) {
 	return register_ipsec_alg((struct ipsec_alg*)ixt);
 }
diff --git a/linux/net/ipsec/ipsec_xmit.c b/linux/net/ipsec/ipsec_xmit.c
index f4a0b51..3cd6f3c 100644
--- a/linux/net/ipsec/ipsec_xmit.c
+++ b/linux/net/ipsec/ipsec_xmit.c
@@ -1953,7 +1953,7 @@ enum ipsec_xmit_value ipsec_nat_encap(struct ipsec_xmit_state *ixs)
 		/* clear UDP & Non-IKE Markers (if any) */
 		memset(udp, 0, ixs->natt_head);
 
-		/* fill UDP with usefull informations ;-) */
+		/* fill UDP with useful informations ;-) */
 		udp->source = htons(ixs->natt_sport);
 		udp->dest = htons(ixs->natt_dport);
 		udp->len = htons(ntohs(ipp->tot_len) - ixs->iphlen);
diff --git a/programs/barf/barf.8 b/programs/barf/barf.8
index 5189969..d577ae1 100644
--- a/programs/barf/barf.8
+++ b/programs/barf/barf.8
@@ -26,7 +26,7 @@ option limits the length of the log portion of
 \fIbarf\fR\'s output, which can otherwise be extremely voluminous if debug logging is turned on\.
 .PP
 \fB\-\-maxlines <100>\fR
-option sets the length of some bits of information, currently netstat \-rn\. Usefull on boxes where the routing table is thousands of lines long\. Default is 100\.
+option sets the length of some bits of information, currently netstat \-rn\. Useful on boxes where the routing table is thousands of lines long\. Default is 100\.
 .PP
 \fIBarf\fR
 censors its output, replacing keys and secrets with brief checksums to avoid revealing sensitive information\.
diff --git a/programs/pluto/connections.c b/programs/pluto/connections.c
index 4261e25..d71d233 100644
--- a/programs/pluto/connections.c
+++ b/programs/pluto/connections.c
@@ -2145,7 +2145,7 @@ route_owner(struct connection *c
 
 /* Find some connection with this pair of hosts.
  * We don't know enough to chose amongst those available.
- * ??? no longer usefully different from find_host_pair_connections
+ * ??? no longer usefuly different from find_host_pair_connections
  */
 struct connection *
 find_host_connection2(const char *func
diff --git a/programs/pluto/pluto.8 b/programs/pluto/pluto.8
index 16523d6..90a7727 100644
--- a/programs/pluto/pluto.8
+++ b/programs/pluto/pluto.8
@@ -842,7 +842,7 @@ When a DPD enabled peer is declared dead, what action should be taken\&.
 \fBhold\fR(default) means the eroute will be put into
 \fI%hold\fR
 status, while
-\fBclear\fRmeans the eroute and SA with both be cleared\&. Clear is really only usefull on the server of a Road Warrior config\&. The action
+\fBclear\fRmeans the eroute and SA with both be cleared\&. Clear is really only useful on the server of a Road Warrior config\&. The action
 \fBrestart\fR
 is used on tunnels that need to be permanently up, and have static IP addresses\&.
 .RE
diff --git a/programs/pluto/vendor.c b/programs/pluto/vendor.c
index 26e65c9..e378479 100644
--- a/programs/pluto/vendor.c
+++ b/programs/pluto/vendor.c
@@ -459,7 +459,7 @@ void init_vendorid(void)
 /**
  * Handle Known VendorID's.  This function parses what the remote peer 
  * sends us, and enables/disables features based on it.  As we go along, 
  * we set vid_usefull =1 if we did something based on this VendorID.  This
  * supresses the 'Ignored VendorID ...' log message.
  *
  * @param md UNUSED - Deprecated
@@ -476,7 +476,7 @@ static void handle_known_vendorid (struct msg_digest *md
 				   , struct state *st UNUSED)
 {
 	char vid_dump[128];
-	int vid_usefull = 0;
+	int vid_useful = 0;
 	size_t i, j;
 
 	switch (vid->id) {
@@ -494,7 +494,7 @@ static void handle_known_vendorid (struct msg_digest *md
 	case VID_NATT_IETF_00:
 	    if (!nat_traversal_support_non_ike)
 		break;
-	    vid_usefull = 1;
+	    vid_useful = 1;
 	    if ((nat_traversal_enabled) && (!md->quirks.nat_traversal_vid)) {
 		md->quirks.nat_traversal_vid = vid->id;
 	    }
@@ -505,7 +505,7 @@ static void handle_known_vendorid (struct msg_digest *md
 	case VID_NATT_IETF_05:
 	case VID_NATT_DRAFT_IETF_IPSEC_NAT_T_IKE:
 	case VID_NATT_RFC:
-	    vid_usefull = 1;
+	    vid_useful = 1;
 	    if(!nat_traversal_support_port_floating) {
 		loglog(RC_LOG_SERIOUS
 		       , "received Vendor ID payload [%s] meth=%d, "
@@ -534,12 +534,12 @@ static void handle_known_vendorid (struct msg_digest *md
         case VID_MISC_DPD:
 	    /* Remote side would like to do DPD with us on this connection */
 	    md->dpd = 1;
-	    vid_usefull = 1;
+	    vid_useful = 1;
             break;
 
 	case VID_MISC_IKEv2:
 	    md->ikev2 = TRUE;
-	    vid_usefull = 1;
+	    vid_useful = 1;
 	    break;
 
 /* We only need these when dealing with XAUTH */
@@ -548,21 +548,21 @@ static void handle_known_vendorid (struct msg_digest *md
 	  loglog(RC_LOG_SERIOUS
 		 , "SSH Sentinel 1.4.1 found, setting XAUTH_ACK quirk");
 	  md->quirks.xauth_ack_msgid = TRUE;
-	  vid_usefull = 1;
+	  vid_useful = 1;
 	  break;
 
 	case VID_CISCO_UNITY:
 	  md->quirks.modecfg_pull_mode= TRUE;
-	  vid_usefull = 1;
+	  vid_useful = 1;
 	  break;
 
 	case VID_MISC_XAUTH:
-	    vid_usefull=1;
+	    vid_useful=1;
 	    break;
 #endif
 	    
 	case VID_OPENSWANSELF:
-	    vid_usefull=1;
+	    vid_useful=1;
 	    break;
 	    
 	default:
@@ -595,7 +595,7 @@ static void handle_known_vendorid (struct msg_digest *md
 	}
 
 	loglog(RC_LOG_SERIOUS, "%s Vendor ID payload [%s]",
-		vid_usefull ? "received" : "ignoring", vid_dump);
+		vid_useful ? "received" : "ignoring", vid_dump);
 }
 
 
@@ -459,7 +459,7 @@ void init_vendorid(void)
  * Handle Known VendorID's.  This function parses what the remote peer 
  * sends us, and enables/disables features based on it.  As we go along, 
- * we set vid_usefull =1 if we did something based on this VendorID.  This
+ * we set vid_useful =1 if we did something based on this VendorID.  This
  * supresses the 'Ignored VendorID ...' log message.
  *
-- 
1.7.0




More information about the Dev mailing list